// ECB/SIS Public License, version 1.0, document reference SIS/2001/116
//
// Copyright (C) 2006 European Central Bank. All rights reserved.
//
// Redistribution and use in source and binary forms,
// with or without modification, are permitted
// provided that the following conditions are met:
//
// Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
// Neither the name of the European Central Bank
// nor the names of its contributors may be used to endorse or promote products
// derived from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
// TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import java.io.File;
import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

public class SAXGetRate extends DefaultHandler {

    private static String currency;

    private static boolean seriesFound = false;

    private static String period;

    private SAXGetRate() {
    }

    public static void main(final String[] args) {
        if (args.length != 3) {
            System.err.println("Usage: cmd filename currency date");
            System.exit(1);
        }

        final SAXGetRate handler = new SAXGetRate();
        currency = args[1];
        period = args[2];
        final SAXParserFactory factory = SAXParserFactory.newInstance();
        try {
            final SAXParser parser = factory.newSAXParser();
            parser.parse(new File(args[0]), handler);
        } catch (final ParserConfigurationException e) {
            e.printStackTrace();
        } catch (final SAXException e) {
            e.printStackTrace();
        } catch (final IOException e) {
            e.printStackTrace();
        }
        System.exit(0);
    }

    public void startElement(final String namespaceURI, final String sName,
            final String qName, final Attributes attrs) {
        if (qName.equals("Series") && attrs != null
                && attrs.getValue("CURRENCY").equals(currency)) {
            seriesFound = true;
        } else if (qName.equals("Series")) {
            seriesFound = false;
        } else if (qName.equals("Obs") && seriesFound
                && attrs.getValue("TIME_PERIOD").equals(period)) {
            System.out.println("Exchange rate value for " + currency + " on "
                    + period + ": " + attrs.getValue("OBS_VALUE"));
            System.exit(0);
        }
    }
}
